package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````4!]```````!``````````-#)````
M`````````$``.``'`$``&@`9``8````%````0`````````!``$```````$``
M0```````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!0```````R`%````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````.RS````````[+,`````````
M`!````````$````&`````,``````````P%````````#`4```````H`<`````
M``"H#```````````$````````@````8```"0PP```````)##4```````D,-0
M``````#P`0```````/`!````````"``````````$````!````.`!````````
MX`%```````#@`4```````!@`````````&``````````$`````````%#E=&0$
M````&+,````````8LT```````!BS0```````U`````````#4``````````0`
M````````+VQI8F5X96,O;&0M96QF+G-O+C$`````"`````0````!````1G)E
M94)31`"X0`P`80```&8````````````````````)`````````%P```!;````
M5P``````````````9`````````!$````6@`````````W````/P```#H````.
M````-@```$@```!/````10```````````````````"$```!8````+@````$`
M````````,0```%$````L````8``````````&````&@```&$````;````````
M`"H`````````7P```!`````M````7@````````!*````*`````4```!-````
M8P```#T```!!````)0```%0````8````90`````````P````(`````````!'
M`````````````````````````%````!#````-````%8```!=````'@``````
M`````````````%4````R````0````%,```!9````#0`````````/````!```
M`````````````````#@`````````'P```!0`````````*P```&(`````````
M````````````````````````````````````````````````````````````
M``````````P`````````````````````````````````````````````````
M```````````````````2`````P```!D````(```````````````+````````
M````````````````````````````````````````````*0`````````=````
M``````H````B`````````"0``````````````````````````@``````````
M```````````````U```````````````\`````````````````````````#D`
M`````````````",````<````!P```"<`````````$0```"8`````````````
M`#X`````````.P```$P````O```````````````S````%P```$L```!"````
M`````!,`````````%@```%(```!.``````````````!)````%0````````!&
M``````````````````````````````````````````P````2````A!M`````
M``"-`````````-<"```2````E!M```````"0`````````!<````2````I!M`
M``````"="````````"D````1`!<`H,=0```````!`````````&$#```2````
MM!M````````/`````````+,#```2``P`\#U```````"^`0```````$`````1
M`/'_D,-0`````````````````.H"```2````Q!M``````````````````/<"
M```2````U!M````````T`````````!T#```2````Y!M```````!5````````
M`$D````2````]!M```````#P`````````%<````2````!!Q```````#D````
M`````&,````2````%!Q````````/`0```````,`#```2``P`X$]````````%
M`````````'0````1`!<`J,=0```````(`````````-$#```1`!``&,!0````
M```(`````````'@"```1`!<`L,=0``````!``````````'X````2````)!Q`
M``````"J!P```````(T````1`!<`\,=0```````(`````````-L#```2``P`
MX#=```````!-`````````)<````2````-!Q````````*`P```````.D#```2
M``P`X#]```````#B`````````"L#```2````1!Q````````"``````````X#
M```2````5!Q```````#(#````````*4````1`!<`^,=0```````!````````
M`!H$```2``H`8!M``````````````````+(````2````9!Q```````!A!0``
M`````+T````2````=!Q```````"0`````````,H````2````A!Q```````!A
M`0```````-@````1`!<`H,Q0```````(`````````.`````2````E!Q`````
M``#%`@```````/\"```2````I!Q```````!,``````````<#```2````M!Q`
M`````````````````/4#```2``P`,$-```````"L`0```````.L````2````
MQ!Q```````!G``````````($```2``P`\$]```````#<`@```````!@$```2
M``P`T%)````````4`````````!8#```2````U!Q````````,`````````-\"
M```1`!```,!0```````(`````````(,#```2``P`4!]```````"<````````
M`%,#```2````Y!Q``````````````````.L"```2````]!Q`````````````
M`````#4#```2````!!U````````*`````````"0#```2````%!U```````!4
M`````````"`$```2``P`X$1````````L"@```````/H````2````)!U`````
M```[!````````+("```2````-!U``````````````````$X"```2````1!U`
M```````Q`````````,`"```2````5!U```````!G`````````"T$```2``P`
MT$!```````!M`````````/`"```2````9!U```````!\``````````,!```1
M`!<`^<=0```````!`````````#T#```2````=!U```````!^`````````!$!
M```2````A!U```````#.`0```````"$!```1`!<``,A0```````(````````
M`'X#```0`/'_H,=0`````````````````&`"```2````E!U```````!#````
M`````#D$```2``P`0$%```````#P`0```````#X$```2``P`T#Q````````7
M`0```````%`$```2``P`$$]```````#)`````````#$!```1`!<`",A0````
M```!`````````#P!```2``T`5%-``````````````````$(!```2````I!U`
M```````?&@```````*$$```2````M!U````````>`````````%L"```2````
MQ!U```````"4`````````'`"```2````U!U```````!*`````````%`!```2
M````Y!U```````!"`````````$X#```2````]!U````````O`````````'$#
M```2````!!Y```````````````````P"```2````%!Y````````\!@``````
M`&`!```2````)!Y````````K`````````'<#```0`/'_H,=0````````````
M`````)$"```2````-!Y```````!*`````````&L!```1`/'_J,50````````
M`````````(H#```0`/'_J,Q0`````````````````+@"```2````1!Y`````
M``!L`````````($!```1`!<`"<A0```````!`````````(P!```1`!<`$,A0
M```````3`````````)@"```1`!<`*,A0```````(`````````!@"```2````
M5!Y````````O!P```````*L"```2````9!Y``````````````````&8$```2
M``P`,#A````````>`````````)L!```2````=!Y```````!\`````````,8"
M```2````A!Y````````,`````````(($```2``P`8"!````````T````````
M`+(!```1`!<`,,A0```````(`````````$P#```2````E!Y````````O````
M`````(\$```2``P`L#]````````B`````````+@!```1`!<`.,A0```````(
M`````````(H"```2````I!Y``````````````````,,!```2````M!Y`````
M``"1`@```````-$!```1`!<`0,A0```````(`````````%H#```2````Q!Y`
M``````#T`````````&@#```2````U!Y```````";`````````%8"```2````
MY!Y```````!G`````````-X!```@`````````````````````````$0#```2
M````]!Y```````"0`````````/(!```2````!!]````````5`````````*("
M```2````%!]````````````````````"```2````)!]````````V````````
M`!,"```2````-!]````````5``````````!L:6)P97)L+G-O`%!E<FQ?8W)O
M86L`4&5R;%]S=E\R<'9?9FQA9W,`4$Q?<&5R;%]D97-T<G5C=%]L979E;`!?
M1%E.04U)0P!097)L7V%V7W-H:69T`%!E<FQ?;6=?<V5T`%!E<FQ?;F5W6%-?
M9FQA9W,`4$Q?8V]M<&-V`'!E<FQ?8V]N<W1R=6-T`%!,7W!A<G-E<@!097)L
M7V1O=6YW:6YD`%!,7V1O7W5N9'5M<`!P97)L7W!A<G-E`%!E<FQ?;F5W4U9P
M=@!097)L7W-V7W-E='!V`&5N=FER;VX`4&5R;%]N97=84P!097)L7W-Y<U]I
M;FET,P!P97)L7W)U;@!03%]E>&ET7V9L86=S`&)O;W1?1'EN84QO861E<@!0
M3%]C=7)S=&%C:VEN9F\`4$Q?=&%I;G1E9`!?9FEN:0!P97)L7V1E<W1R=6-T
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7V%L;&]C`%]'3$]"04Q?3T9&4T547U1!
M0DQ%7P!03%]I;E]E=F%L`%!,7VUE;6]R>5]W<F%P`%!E<FQ?<V%V95]D97-T
M<G5C=&]R7W@`4$Q?;W``4$Q?=&]P7V5N=@!097)L7V%V7V9E=&-H`%!,7V5V
M86Q?<F]O=`!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S869E<WES;6%L;&]C`'!E<FQ?9G)E90!L:6)M+G-O+C4`;&EB8W)Y<'0N
M<V\N-0!L:6)U=&EL+G-O+C@`;&EB=&AR+G-O+C,`7U]E<G)O<@!R96%D`&]P
M96X`8VQO<V4`;&EB8RYS;RXW`&UE;6UO=F4`7U]S=&%C:U]C:&M?9W5A<F0`
M9V5T<&ED`&UE;6-P>0!?7W-T9&5R<G``<F5A9&QI;FL`9V5T=6ED`')M9&ER
M`')E861D:7(`;'-E96L`7U]S=&%C:U]C:&M?9F%I;`!F<')I;G1F`%]?<')O
M9VYA;64`;'-T870`<W1R<W1R`'-T<FYC;7``<W1R;F-P>0!U;FQI;FL`<F5A
M;&QO8P!S=')T;VL`<W1R9'5P`&UE;7-E=`!?:6YI=%]T;',`;W!E;F1I<@!S
M=')C;7``<W!R:6YT9@!A=&5X:70`86-C97-S`'-T<FQE;@!E>&5C=G``8VQO
M<V5D:7(`;6MD:7(`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L;V-A
M;"]L:6(O<&5R;#4O-2XQ-"]M86-H+T-/4D4`<&%R7VEN:71?96YV`'!A<E]C
M=7)R96YT7V5X96,`;7E?<&%R7W!L`'!A<E]E;G9?8VQE86X`<&%R7V1I<FYA
M;64`<&%R7V9I;F1P<F]G`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET
M`'!A<E]M:W1M<&1I<@!P87)?8VQE86YU<`!M86EN`'!A<E]S971U<%]L:6)P
M871H`'!A<E]C=7)R96YT7V5X96-?<')O8P!84U]);G1E<FYA;'-?4$%27T-,
M14%24U1!0TL`<&%R7V)A<V5N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`$9"4T1?,2XP`````````@```````@`!``$``@`"``(``````````0``
M``$``@```````0````$``@`"`````0`````````!`````@`"``$````!``$`
M`@`!``$``@`"``(``@`!`````@`#``(``0`"`````@```````0`#``$``0`!
M`````0````(``P`"`````@`"``(````!``(``0`!``(```````(``@`"``$`
M```"``$````"``$````"```````"``(``P````(````"```````!``$`0@(`
M`!`````@````L"AZ!P```P"J!`````````$``0!F`@``$`````````"P*'H'
M```"`*H$````````H,=0```````%````!```````````````J,=0```````%
M````#P``````````````L,=0```````%````$0``````````````\,=0````
M```%````$P``````````````^,=0```````%````&0``````````````^<=0
M```````%````-````````````````,A0```````%````-P``````````````
M",A0```````%````/0``````````````"<A0```````%````30``````````
M````$,A0```````%````3@``````````````*,A0```````%````3P``````
M````````,,A0```````%````5@``````````````.,A0```````%````60``
M````````````0,A0```````%````7```````````````P,50```````'````
M`0``````````````R,50```````'`````@``````````````T,50```````'
M`````P``````````````V,50```````'````!0``````````````X,50````
M```'````"```````````````Z,50```````'````"0``````````````\,50
M```````'````"@``````````````^,50```````'````"P``````````````
M`,90```````'````#```````````````",90```````'````#0``````````
M````$,90```````'````$@``````````````&,90```````'````%0``````
M````````(,90```````'````%P``````````````*,90```````'````&```
M````````````,,90```````'````&P``````````````.,90```````'````
M'```````````````0,90```````'````'0``````````````2,90```````'
M````'P``````````````4,90```````'````(```````````````6,90````
M```'````(0``````````````8,90```````'````(P``````````````:,90
M```````'````)@``````````````<,90```````'````*0``````````````
M>,90```````'````*@``````````````@,90```````'````*P``````````
M````B,90```````'````+```````````````D,90```````'````+@``````
M````````F,90```````'````+P``````````````H,90```````'````,```
M````````````J,90```````'````,0``````````````L,90```````'````
M,P``````````````N,90```````'````-0``````````````P,90```````'
M````-@``````````````R,90```````'````.0``````````````T,90````
M```'````/P``````````````V,90```````'````0```````````````X,90
M```````'````00``````````````Z,90```````'````0@``````````````
M\,90```````'````0P``````````````^,90```````'````1```````````
M`````,=0```````'````10``````````````",=0```````'````1@``````
M````````$,=0```````'````1P``````````````&,=0```````'````20``
M````````````(,=0```````'````3```````````````*,=0```````'````
M4```````````````,,=0```````'````40``````````````.,=0```````'
M````4P``````````````0,=0```````'````5```````````````2,=0````
M```'````5P``````````````4,=0```````'````6@``````````````6,=0
M```````'````6P``````````````8,=0```````'````70``````````````
M:,=0```````'````7@``````````````<,=0```````'````7P``````````
M````>,=0```````'````80``````````````@,=0```````'````8@``````
M````````B,=0```````'````8P``````````````D,=0```````'````9```
M````````````F,=0```````'````90``````````````2(/L".C'!```Z+(W
M``!(@\0(PP#_-3:J$`#_)3BJ$`"0D)"0_R4VJA``:`````#IX/____\E+JH0
M`&@!````Z=#_____)2:J$`!H`@```.G`_____R4>JA``:`,```#IL/____\E
M%JH0`&@$````Z:#_____)0ZJ$`!H!0```.F0_____R4&JA``:`8```#I@/__
M__\E_JD0`&@'````Z7#_____)?:I$`!H"````.E@_____R7NJ1``:`D```#I
M4/____\EYJD0`&@*````Z4#_____)=ZI$`!H"P```.DP_____R76J1``:`P`
M``#I(/____\ESJD0`&@-````Z1#_____)<:I$`!H#@```.D`_____R6^J1``
M:`\```#I\/[___\EMJD0`&@0````Z>#^____):ZI$`!H$0```.G0_O___R6F
MJ1``:!(```#IP/[___\EGJD0`&@3````Z;#^____)9:I$`!H%````.F@_O__
M_R6.J1``:!4```#ID/[___\EAJD0`&@6````Z8#^____)7ZI$`!H%P```.EP
M_O___R5VJ1``:!@```#I8/[___\E;JD0`&@9````Z5#^____)6:I$`!H&@``
M`.E`_O___R5>J1``:!L```#I,/[___\E5JD0`&@<````Z2#^____)4ZI$`!H
M'0```.D0_O___R5&J1``:!X```#I`/[___\E/JD0`&@?````Z?#]____)3:I
M$`!H(````.G@_?___R4NJ1``:"$```#IT/W___\E)JD0`&@B````Z<#]____
M)1ZI$`!H(P```.FP_?___R46J1``:"0```#IH/W___\E#JD0`&@E````Z9#]
M____)0:I$`!H)@```.F`_?___R7^J!``:"<```#I</W___\E]J@0`&@H````
MZ6#]____)>ZH$`!H*0```.E0_?___R7FJ!``:"H```#I0/W___\EWJ@0`&@K
M````Z3#]____)=:H$`!H+````.D@_?___R7.J!``:"T```#I$/W___\EQJ@0
M`&@N````Z0#]____);ZH$`!H+P```.GP_/___R6VJ!``:#````#IX/S___\E
MKJ@0`&@Q````Z=#\____)::H$`!H,@```.G`_/___R6>J!``:#,```#IL/S_
M__\EEJ@0`&@T````Z:#\____)8ZH$`!H-0```.F0_/___R6&J!``:#8```#I
M@/S___\E?J@0`&@W````Z7#\____)7:H$`!H.````.E@_/___R5NJ!``:#D`
M``#I4/S___\E9J@0`&@Z````Z4#\____)5ZH$`!H.P```.DP_/__````````
M````````54B)Y4%53(UO"$%44TB#[`B+'TACPX7;3(UDQQ!,B24LK1``?CI(
MBU<(2(72=#%(B15ZH!``#[8"A,!T(TB#P@$\+TB+!6:@$`!(#T3"2(D%6Z`0
M``^V`DB#P@&$P'7AN)##4`!(A<!T*TB)]^C2_O__OU130`#HR/[__^B/^___
MB=],B>),B>[H8B$``(G'Z`_^___H6OS__^O6D)"0D(`]4:@0``!52(GE=!#K
M))!(@\`(2(D%!:`0`/_22(L%_)\0`$B+$$B%TG7DQ@4EJ!```<G#9F9FD&9F
M9I!F9I!52(,]9Z40``!(B>5T%K@`````2(7`=`R_H,50`$F)P\E!_^/)PY"0
MD)"0D)"0D)`/M@](B?B$R70H2(L%5S4``$B-5P$/MC!(B?AF9I!FD$`X\0^V
M"D@/1,)(@\(!A,EU[O/#9F9FD&9F9I!F9F:0059(C7<X055!5%5(B?U32('L
M"`(``$R-3"2(38V!@````$R)STB+#DB#Q@A(B<I(B<A(P>((2,'@&"4```#_
M@>(``/\`2`G"2(G(2,'H""4`_P``2`G"2(G(2,'H&"7_````2`G"2(G(2,'I
M*$C!Z"!(B1=(P>`(2(G"2,'@$"4```#_@>(``/\`2`G"2(G(2,'I$"4`_P``
M2`G"2`G*2(E7"$B#QQ!,.<</A77___])C4EH28VQ:`(``&9FD&:02(L!2#-!
MV$@S0:A(,T&82(G"2`'`2,'J'T@)PH/B_TB)41A(@\$(2#GQ==1,BW4`2(M\
M)(A!O=R\&X](`WT@2(M-"$R+51!(BW483(GP3(GR38GQ2,'B!4C!Z!M)B<A(
M"=!,B=))P>@"@^#_2"'*2<'I`DB-O`>9>8):2(G(2,'A'DCWT$D)R$@A\$&#
MX/](`W0DD$@)T$R)P@''3(GP3"'R2/?02(GY3"'02,'I&TP#5"282`G"2(GX
M2,'@!4B-M!:9>8):2(GZ2`G!3(GP2,'@'@'Q20G!2(GX2(G.08/A_TCWT$C!
M[AM,(<I,(<!("=!(B<I-C90"F7F"6DB)R$C!X`5("<9(B<A$`=9)B?I(]]!)
MP>H"2,'G'DP#1"2@20GZ3"'(2(GW08/B_TC![QM,`TPDJ$PATD@)T$B)\DV-
MA`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY
M08/@_TC!Z1M,`U0DL$PAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!
MR4F)\4C!YAY)P>D"2/?020GQ3"'`2(G.08/A_TC![AM,(<I("=!(B<I-C90"
MF7F"6DB)R$C!X`5,`T0DN$@)QDB)R$0!UDF)^DC!YQY)P>H"2/?020GZ3"'(
M2(GW08/B_TC![QM,`TPDP$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)
M\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,`U0DR$PAPD@)
MT$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)\4C!YAY)P>D"2/?020GQ
M3"'`2(G.08/A_TPARDC![AM,`T0DT$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)
MQDB)R$0!UDF)^DC!YQY)P>H"2/?020GZ3"'(2(GW08/B_TC![QM,`TPDV$PA
MTD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?0
M20G(3"'02(GY08/@_TC!Z1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5("<%(
MB?A$`<E)B?%(P>8>2<'I`DCWT$D)\4B)SD&#X?],`U0DX$PAP$PARDC![AM,
M`T0DZ$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!YQY)P>H"
M2/?020GZ3"'(2(GW08/B_TC![QM,`TPD\$PATD@)T$B)\DV-A`"9>8):2(GP
M2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,
M(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$`<E)B?%(]]!)P>D"2,'F
M'DP#5"3X20GQ3"'`2(G.08/A_TC![AM,`P0D3"'*2`G02(G*38V4`IEY@EI(
MB<A(P>`%2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)B?-)"?I,(<A(B?=!@^+_
M2,'O&TP#3"0(3"'22`G02(GR38V$`)EY@EI(B?!(P>`%2`G'2(GP1`''28G(
M2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TPAPD@)T$B)^DV-C`&9>8):
M2(GX2,'@!4C!YAY)P>L"3`-4)!!("<%)"?-(B?A!@^/_1`')2/?03"':2(G.
M3"'`28GY2,'N&T@)T$C!YQY)P>D"38V4`IEY@EI(B<A,`T0D&$C!X`5)"?E(
MB<I("<9(B<A!@^'_2/?03"'*1`'63"'82(GW28G*2`G02,'A'DC![QM-C80`
MF7F"6DB)\$G!Z@)(P>`%3`-<)"!)"<I("<=(B?!!@^+_2(GR2/?01`''3"'(
M28GP3"'22`G02,'F'DG!Z`)-C9P#F7F"6DD)\$B)^DB)^$&#X/],`TPD*$C!
MX`5(P>H;2`G"3(G`3#'01`':3`-4)#!(,?A(B=%-C8P!H>O9;DB)T$C!Z1M(
MP>`%2`G!1`')28GY2,'G'DG!Z0)(B<Y)"?E(B==(P>X;08/A_TC![P),B<A,
M,<!,`T0D.$@QT$C!XAY-C90"H>O9;D@)UTB)R(/G_TC!X`5("<9(B?A$`=9,
M,<A,`TPD0$@QR$B)\DV-A`"AZ]EN2(GP2,'J&TC!X`5("<)$`<))B<A(P>$>
M2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`-\)$A(,?!-C8P!H>O9;DB)T$C!
MX`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`3`-$)%!(
M,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G72(GR@^?_2(GX
M3#'(2,'J&TP#3"182#'(38V$`*'KV6Y(B?!(P>`%2`G"1`'"28G(2,'A'DG!
MZ`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#?"1@2#'P38V,`:'KV6Y(B=!(P>`%
M2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#1"1H2#'0
M2(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(B==(P>(>2,'O`D@)UTB)\H/G_TB)^$PQ
MR$C!ZAM,`TPD<$@QR$V-A`"AZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"
M20G(2(G108/@_TC!Z1M,B<!(,?A(`WPD>$@Q\$V-C`&AZ]EN2(G02,'@!4@)
MP40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,B<A,,<!,`X0D@````$@Q
MT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)("==(B?*#Y_](B?A,
M,<A(P>H;3`.,)(@```!(,<A-C80`H>O9;DB)\$C!X`5("<)$`<))B<A(P>$>
M2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`.\))````!(,?!-C8P!H>O9;DB)
MT$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`3`.$
M))@```!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G72(GR
M@^?_2(GX3#'(2,'J&TP#C"2@````2#'(38V$`*'KV6Y(B?!(P>`%2`G"1`'"
M28G(2,'A'DG!Z`))B=))"<A(B=%)P>H"08/@_TC!Z1M,B<!(,?A(`[PDJ```
M`$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"28G,20GQ2(G.
M08/A_TC![AM,B<A,,<!,`X0DL````$@QT$C!XAY(C;P'H>O9;DD)TDB)R$&#
MXO](P>`%2`G&3(G0`?Y,,<A)P>P"2#'(2,'A'DB)\DV-A`"AZ]EN20G,2(GP
M08/D_TP#C"2X````2,'@!4C!ZAM(B?-(BXPDR````$@)PDR)X$C!ZP),,=!$
M`<),`Y0DP````$@Q\$C!YAY(B==-C8P!H>O9;D@)\TB)T(/C_TC!X`5(P>\;
M2`G'2(G828G33#'@1`'/2<'K`D@QT$C!XAY)B?A-C90"H>O9;DD)TTB)^$&#
MX_](P>`%2<'H&TD)P$P!Z4R)V$4!T$R)VDP!X4@)V$@AVDR)QD@A^$F)^4C!
M[AM("=!(P><>2<'I`D@!P4R)P$D)^4C!X`5!@^'_38G"2`G&3(G(3(G*`<Y(
MBXPDT````$P)V$PAVDPAP$B)]T@)T$C![QM)P>`>3`'I2<'J`D&\UL%BRD@!
MV4T)PD@!P4B)\$&#XO](P>`%3(G22`G'3(G0`<](BXPDV````$P)R$@A\$F)
M^$P!Z4P!V4PARDF)\T@)T$C!YAY)P>@;2`'!2(GX2<'K`DC!X`5)"?-)"<!!
M@^/_00'(2(N,).````!,B=A,"=!,B=I,B<9,(=)((?A(P>X;3`'I2`G03`')
M28GY2,'G'D@!P4R)P$G!Z0)(P>`%20GY2`G&08/A_P'.2(N,).@```!,B<A,
M"=A,B<I(B?=,(=I,(<!,`>E("=!,`=%-B<)(`<%(B?!(P>\;2,'@!4G!X!Y)
MP>H"2`G'30G"`<]!@^+_2(N,)/````!,B=!,B=))B?A,"<A,(<I)P>@;3`'I
M2"'P2`G03`'928GS2`'!2(GX2,'F'DC!X`5)P>L"20G`20GS00'(08/C_TB+
MC"3X````3(G83(G:3(G&3`G03"'22,'N&TP!Z4@A^$@)T$P!R4F)^4@!P4R)
MP$C!X`5("<8!SDC!YQY)P>D"20GY2(N,)``!``!(B?=!@^'_2,'O&TR)R$R)
MRDP)V$PAVDP!Z4PAP$P!T4V)PD@)T$G!X!Y)P>H"2`'!2(GP30G"2,'@!4&#
MXO]("<=,B=!,B=(!STB+C"0(`0``3`G(3"'*2"'P28GX2`G02<'H&TP!Z4P!
MV4F)\TC!YAY(`<%(B?A)P>L"2,'@!4D)P$$!R$D)\TB+C"00`0``08/C_TR)
MQDR)V$R)VDC![AM,"=!,(=),`>E((?A,`<E)B?E("=!(P><>2<'I`D@!P4R)
MP$D)^4C!X`5!@^'_2`G&3(G(3(G*`<Y(BXPD&`$``$P)V$PAVDPAP$B)]T@)
MT$C![QM,`>E,`=%-B<))P>`>2`'!2(GP2<'J`DC!X`5-"<)("<=!@^+_`<](
MBXPD(`$``$R)T$R)TDF)^$P!Z4P!V4P)R$PARD@A\$F)\TG!Z!M("=!(P>8>
M2<'K`D@!P4B)^$D)\TC!X`5!@^/_20G`3(G83(G:00'(2(N,)"@!``!,"=!,
M(=)((?A,B<9("=!(P>X;3`'I3`')28GY2,'G'D@!P4R)P$G!Z0)(P>`%20GY
M2`G&08/A_P'.2(N,)#`!``!,B<A,"=A,B<I(B?=,(<!,`>E,`=%,(=I-B<)(
M"=!)P>`>2,'O&T@!P4B)\$G!Z@)(P>`%30G"2`G'08/B_P'/2(N,)#@!``!,
MB=!,"<A,B=))B?A,(<I((?!)P>@;3`'I2`G03`'928GS2,'F'D@!P4B)^$G!
MZP)(P>`%20GS20G`08/C_T$!R$B+C"1``0``3(G83`G03(G:3(G&3"'22"'X
M3`'I2`G03`')28GY2`'!3(G`2,'N&TC!X`5(P><>2<'I`D@)QDD)^0'.08/A
M_TB+C"1(`0``3(G(3(G*2(GW3`G83"':2,'O&TP!Z4PAP$@)T$P!T4V)PD@!
MP4B)\$G!X!Y(P>`%2<'J`D@)QTT)P@'/08/B_TB+C"10`0``3(G03(G228GX
M3`G(3"'*2<'H&TP!Z4@A\$@)T$P!V4F)\T@!P4B)^$C!X`5)"<!!`<A(P>8>
M2<'K`DD)\TB+C"18`0``3(G&08/C_TC![AM,B=A,B=I,`>E,"=!,(=),`<E(
M(?A)B?E("=!(P><>2<'I`D@!P4D)^4R)P$&#X?],`ZPD8`$``$C!X`5("<9,
MB<A,B<I,"=A,(=H!SDPAP$B)]T@)T$T!U4C![QM)`<5(B?!-B<)(P>`%2<'@
M'DG!Z@)("<=(BY0D:`$``$0![TT)PDF)\$&#XO](B?E)P>@"3(G03`'B2,'I
M&TPQR$P!VD@Q\$C!YAY(`<)(B?A)"?!(P>`%08/@_T@)P4R)P`'12(N4)'`!
M``!,,=!(,?A(B<Y(P>X;3`'B3`'*28GY2,'G'D@!PDB)R$G!Z0)(P>`%20GY
M2`G&08/A_P'62(N4)'@!``!,B<A,,<!(B?=(,<A,`>),`=))B<I(`<)(B?!(
MP>\;2,'@!4C!X1Y)P>H"2`G'20G*`==(BY0D@`$``$&#XO],B=!(B?E,,<A(
MP>D;3`'B2#'P3`'"28GP2,'F'D@!PDB)^$G!Z`)(P>`%20GP2`G!08/@_P'1
M2(N4)(@!``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*28GY2,'G'D@!PDB)R$G!
MZ0)(P>`%20GY2`G&`=9(BY0DD`$``$&#X?],B<A(B?=,,<!(P>\;3`'B2#'(
M3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4))@!``!,
MB=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!PDB)^$G!Z`)(P>`%20GP
M2`G!08/@_P'12(N4)*`!``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*28GY2`'"
M2(G(2,'@!4C!YQY)P>D"2`G&20GY`=9(BY0DJ`$``$&#X?],B<A(B?=,,<!(
MP>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'7
M2(N4)+`!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!PDB)^$G!
MZ`)(P>`%20GP2`G!08/@_P'12(N4)+@!``!,B<!(B<Y,`>),,=!(P>X;2#'X
M3`'*28GY2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY`=9(BY0DP`$``$&#X?],
MB<A(B?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*
M2`G'08/B_P'72(N4),@!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2`'"
M2(GX2,'@!4@)P4C!YAY)P>@"`=%)"?!(BY0DT`$``$&#X/](B<Y,B<!(P>X;
M3`'B3#'02#'X3`'*28GY2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY`=9(BY0D
MV`$``$&#X?],B<A(B?=)B?-,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)
M\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4).`!``!,B=!(B?E(B?M,`>),`<),
M,<A(P>D;2#'P2<'K`DC!YAY(`<)(B?A)"?-(P>`%08/C_TC!ZP)("<%,B=@!
MT4B+E"3H`0``3#'02#'X28G(2,'G'DG!Z!M("?M,`>*#X_],`<I)B<E(`<)(
MB<A(P>`%20G`2(G800'02(N4)/`!``!,,=A(,<A,B<=,B<9(P>\;3`'B3`'2
M2`'"3(G`2,'@!4@)QP'72,'A'DG!Z0))"<E(BY0D^`$``$C![@)!@^'_2(GY
M3(G(2,'I&TP!XD@QV$P#I"0``@``3#'`3`':2<'@'D@!PDP)QDB)^$C!X`6#
MYO]("<%(B?!)`=Q,,<@!T4@Q^$B)RDD!Q$B)R$C!X@5(P>@;2`G01`'@1`'P
M2(E%`$B)^$C!YQY(P>@"`TT(2`GX`T40`W481`--($B)30A(B4402(EU&$R)
M32!(@<0(`@``6UU!7$%=05[#3(ED).!,B7PD^$F)_$B)7"302(EL)-A)B?=,
MB6PDZ$R)="3P2(/L.$B%_W4E,<!(BUPD"$B+;"003(MD)!A,BVPD($R+="0H
M3(M\)#!(@\0XPTR+-;>5$`!-A?9TSP^V!X3`=00QP.L7/#U(B?IT]4B#P@$/
MM@*$P'5%B=!$*>!)BRY(A>UTI4QCZ$R)\V:03(GJ3(GF2(GOZ*;D__^%P'4*
M28U$+0"`.#UT&DB+:PA(@\,(2(7M==?I;____V:0/#UUK.NU3"GS2(/``4C!
M^P-!B1_I5O___V9F9I!F9I!54TB)^TB#[!A(C6PD%&:0,<!(B>Y(B=_H`___
M_TB%P'0F2&-$)!1(C13%`````$@#%?J4$`!(@\((2(L"2(7`2(E"^'7PZ\A(
M@\086UW#D$B#[!@QP$B-="04Z,#^__](@\08PV9F9I!F9F:09F:02(/L"(,]
M-8@0`/]T"XL%+8@0`$B#Q`C#,<"_ME-``.B\____2(7`=`</M@"$P'43,<")
M!0B($`"+!0*($`!(@\0(PSPP#Y7`#[;`Z^5F9I!(@^P(O______H]N/__S'V
MOU`X0`!(@\0(Z2;F__]FD$B+!:F/$`!3,?:_6%5``$B+2`A(BP7&CQ``#[=0
M(`^V!92/$`!F@>+_`8/@?\'B!PG"9HE1`DB+!7./$`!(BU@(Z-[C__](B4,H
M2(L%7X\0`$B+4`A(BP64CQ``2(E",$B+!4F/$``QTDB+2`A(BP4LCQ``2(7`
M=`=(BY"H````2(E1.$B+!26/$`!(BT`(2,=`0`````!(BP42CQ``2(M`"$C'
M0"``````2(L%_XX0`$B+4`A(BP4LCQ``2(E"2%O#9F9FD&9F9I!F9I!F9I!,
MB60DZ$B)7"3828G\2(EL).!,B6PD\$R)="3X2('LJ````$B%_W0%@#\`=3-(
MBYPD@````$B+K"2(````3(ND))````!,BZPDF````$R+M"2@````2('$J```
M`,-F9I#H?^/__TB%P$B)Q73`9F:02(GOZ*SD__](A<`/A*$```!(C5@(O\%3
M0`"Y`@```/Q(B=[SIG39O\!30`"Y`P```$B)WO.F=,A,B>?H].3__TB)WTF)
MQ>CIY/__08U$!0)(8_CH+.3__TB)V4B)QTF)Q4R)XK[#4T``,<#H].3__TB)
MYDR)[^CIXO__@\`!=!$/MT0D""4`\```/0!```!T-DR)[^B+XO__3(GOZ"/D
M__](B>_H"^3__TB%P`^%7____TB)[^B*Y/__3(GGZ.+B___I]O[__TR)[^C!
M_O__D.O'9F9FD&9F9I!F9I!F9I!32(G[2(/$@$B)YNA$X?__A<!U&`^W1"0(
M)0#P```]`$```'0//0"@``!T"$B#[(`QP%O#2(G?O@(```#H,^+__X7`#Y3`
M2(/L@%L/ML##D$%7,<!!5DF)_D%505152(GU4TB#[!B`/CT/E,!(`<5(B>_H
MW>/__TB-="0408G'3(GW,<#HE_O__TB%P$B)PW0W2(G'Z+OC__]$B?I(.=`/
M@KP````/MD4`2(/%`8@#2(/#`83`=>Y(@\08,<!;74%<05U!7D%?PTB+/6&1
M$`!%,>2X$````$B#/P!T'TB)^DB+0@A!@\0!2(/""$B%P'7O08U$)`)(F$C!
MX`.+%>Z,$`"%T@^%$`$``$B)Q\<%V8P0``$```#HB.+__TB%P$F)Q0^$&0$`
M`$ECQ$B+-?Z0$`!,B>](C1S%`````$B)VN@?XO__3(DMY)`0`$B+!=V0$`!(
MQT0#"`````!$B60D%$$/MA9,B?"$T@^%B````(M<)!1%*?=!C7P'`DC!XP-(
M`QVID!``Z!CB__](A<!(B0,/A*D```"+5"042(L%C9`0`$B+%-!!#[8&A,"(
M`G0E/#UT(4R)]^L.9F:09F:02(/'`3P]=`X/MD<!2(/"`83`B`)UZL8"/69F
M9I!F9I`/MD4`2(/%`8A"`4B#P@&$P'7MZ;_^__^`^CT/A&____](@\`!#[8(
MA,D/A&#___^`^3UU[.E6____2(G&9F:0Z+_?__](A<!(B04!D!``=!!)8\1(
MC1S%`````.D+____2(/$&+C_____6UU!7$%=05Y!7\-F9F:09F9FD&9FD$%7
M059)B?Y!54%40;S34T``55-(@^Q(3(L]XA@``$F)Y4C'!"334T``2,=$)`C)
M4T``2,=$)!#64T``2,=$)!C,4T``2,=$)"#14T``2,=$)"CC4T``2,=$)#``
M````ZQY,B?9,B><QP.B"_?__38ME"$F#Q0A-A>0/A(D````QP$R)Y^AG^O__
M2(7`2(G%=-"`.`!TRTR)]DB)Q^CSW___2(7`=<A,B??H1N'__TR)_TB)P^@[
MX?__2(U<`P%(B>_H+N'__TB-/`/H=>#__TF)Z$B)QTB)PTR)^4R)\KX"54``
M,<#H.N'__TR)YS'`2(G>Z/G\__]-BV4(28/%"$V%Y`^%=____TB#Q$A;74%<
M05U!7D%?PV9FD&9FD&9FD$B#[#B_[E-``$B+!;")$`!(B40D*#'`2(L%DA<`
M`$B)!"1(BP6/%P``2(E$)`A(BP6+%P``2(E$)!!(BP6'%P``2(E$)!@/MP6#
M%P``9HE$)"`QP.@G^?__,<"_]U-``.@;^?__,<"__U-``.@/^?__,<"_"%1`
M`.@#^?__,<"_#U1``.CW^/__,<"_'U1``.CK^/__,<"_*U1``.C?^/__,<"_
MME-``.C3^/__,<"_-%1``.C'^/__,<"_/E1``.B[^/__,<"_2%1``.BO^/__
M,<"_551``.BC^/__,<"_7E1``.B7^/__,<"_:51``.C;^/__2(7`=`](B<:_
M-%1``#'`Z,?[__\QP+]Z5$``Z+OX__](A<!T#TB)QK^,5$``,<#HI_O__S'`
MOY=40`#HF_C__TB%P'0V2(G&ORM40``QP.B'^___,<"^PU1``+\/5$``Z';[
M__](BT0D*$@S!5J($`!U44B#Q#C#9F:0,<"_IU1``.A4^/__2(7`=!%(B<:_
MME-``#'`Z$#[___KMTB-="01O[A40`"Y"@```/SSIG6C2(UT)!N_ME-``#'`
MZ!G[___KD.C6WO__9I!(@^P(Z*O>__^)Q^CTW?__,=)(A<!T`TB+$$B)T$B#
MQ`C#9F9FD&9F9I!F9I!F9I!54TB)^TB#[`A(A?]T"`^V+T"$[7402(/$"+_!
M4T``6UWIWMO__^BYWO__2`'82(U0_T@YTP^#G@```$B+/:85```/MD#_#[8W
M0#CP=`GK*@^V"CC!=69(@^H!2#G39I!R[D@YVG4I0#HO=*I(@\0(6UWIC=O_
M_P^V`D`XQG3C2(/J`4@YTW+OZ]AF9I!F9I!(@^H!2#G3<PD/M@(Z!V:0=.Y(
M*=HQR4B-0@)(/0`$``!V#DB#Q`A(B<A;7<.)R.NY2(/"`4B)WK^`R%``Z/+;
M__^Y@,A0`.O:2(L]"!4``.N`9F9FD&9F9I!F9I!F9I!(B5PD\$B);"3X2(/L
M&$B)^^CZ_O__2(G'Z'+?__](B<4QP.CH]O__A<!T"DB%VW0%@#L`=0](BUPD
M"$B+;"002(/$&,.^Q51``$B)[^A"W/__2#G%==](B=](BVPD$$B+7"0(2(/$
M&.GC]___9F:04TB#["")?"0<2(ET)!!(C7PD'$B)5"0(2(UT)!!(C50D".A=
MV___@#V*AA````^$*0$``(M$)!R`#7J&$``#@\`%2&/(2(7)#XA*`0``\D@/
M*L'R#U@%'7$``&8/+@4=<0``#X=,`0``2(T\S0````#H;MW__TB+="002(G!
M2(D%TXH0`$R-2?A(BP9(QT$(RE1``$B)`4B+!3I^$`!(QT$8S51``$B)01!$
MBT0D',<%EXH0``0```!!@_@!?B9,C4GXOP$```"Z"````&9FD$B+!!:#QP%(
MB40*&$B#P@A!.?A_ZT&-0`2^\%)``$4QP$B82<<$P0````"+5"0<2(L].HH0
M`(/"`^@6VO__A<")PW1Q2(L])8H0`.A$V___,<"_'U1``.A4]?__2(7`=!E(
MBST(BA``Z+?<___H@MS__XG82(/$(%O#2(L]]XD0`$B%_W1PZ#7^___KU&9F
MD.A_V___2(7`2(G'2(D%SHD0`'1TZ&O9___&!>"$$```Z:_^__](BSVTB1``
MZ%/:__^)P^E\____2(G(2(G*2-'H@^(!2`G0\D@/*L#R#UC`Z9[^__^^$,A0
M`+]/54``,<#H?MC__[\K5$``Z+#T__](A<!(B<=(B05KB1``#X5S____Z4G_
M__]`MP'HQ-K__T%7059!54%428G\ORM40`!54TB)\TB![*@$``!(BP5=A!``
M2(F$))@$```QP.A>]/__2(LM7Q(``$R)YTF)Q4B)[NCMV?__2(7`=#E,B>:_
M2%1``#'`Z#7W__](BY0DF`0``$@S%1:$$`!,B>`/A30!``!(@<2H!```6UU!
M7$%=05Y!7\-,B>?H!]O__TR+/0P2``!(B=]!B<9,B?[H`MG__TB%P$B)PW2B
M08/&`42)="0,3(VT))````!F9I!FD(`[`+C!4T``2`]$V$V%[70/2(G>3(GO
MZ&C9__^%P'1^2(G?Z*S:__^)P4B8#[9$`_\Z10!U'8U!_TB82(T4&)`/MD+_
MQ@(`@^D!2(/J`3I%`'3MBT0D#`'(/?\#```/CRC___]-B>!(B>E(B=J^`E5`
M`$R)]S'`Z(C:__](C70D$$R)]^A[V/__A<!U$0^W1"08)0#P```]`(```'0;
M,?],B?[H/-C__TB%P$B)PP^%3/___^G3_O__O@$```!,B??H+MC__X7`==1,
MB?:_2%1``.CY]?__3(GWZ!77__])B<3IM/[__^BHV?__9F9FD$%728G_ORM4
M0`!!5D%505154TB![.B!``!(BP6P@A``2(F$)-B!```QP$C'A"30````T%1`
M`$C'A"38````U51``$C'A"3@`````````.B-\O__2(7`2(G#=`F`.``/A8\"
M```QP$B-K"30````Z%WZ__](A<!(B<,/A,<!``!(B=_H7=G__TB-?``!Z*/8
M__^`.P!)B<5T)DB)Q69F9I`/MA-(B>\QP+[E5$``2(/#`4B#Q0+H6MG__X`[
M`'7A2(VL)*````"_C%1``$C'A"2@````C%1``$C'A"2H````A51``$C'A"2P
M````ZE1``$C'A"2X````HE1``$C'A"3`````\E1``$C'A"3(`````````.L1
M2(M]"$B#Q0A(A?\/A$X!```QP.BR\?__2(7`2(G#=."`.`!TVTB)Q^A-]/__
MA<!TSTB)W^BUU?__2(7`28G$#X0=`0``3(GGZ('8__],B>](B</H=MC__XV$
M`P0$``!(8^A(B>_HM-?__TB+%6$/``!(B<=)B<9-B>E!N,540`"^`%5``#'`
M2(G12(E4)!!,B>+H9]C__[[``0``3(GWZ&K7__^#P`$/A$@!``!(C70D($R)
M]^@4U?__A<!U%0^W1"0H)0#P```]`$````^$6`$``$F+%TB+/56!$`!,B?&^
M&%9``#'`,>WHL-3__TB+E"38@0``2#,5O8`0`$B)Z`^%<P(``$B!Q.B!``!;
M74%<05U!7D%?PTB)Q^C.U/__2(G#2(/%"$B%VP^%.?[__TB+?0!(A?\/A#("
M```QP.B&\/__2(7`=-J`.`!URDB#Q0A(A=MTV69FD.D*_O__13'D@#V7#0``
M`$C'A"3P````]E1``+OV5$``2,>$)/@```#!4T``2,>$)``!````````2(VL
M)/````!U*.FD_O__387D#X6;_O__2(M="$B%VP^$CO[__TB#Q0B`.P`/A('^
M__](B=_HKO+__X7`=-%(B=_H%M3__TF)Q.O$2(G'Z/7T__](B=_H`=3__TB)
MQ>GY_O__Z%35__^#.!$/A*K^___H1M7__TF+%T2+`$R)\4B+/1J`$`"^V%5`
M`#'`,>WH>-/__^G#_O__BUPD+.@ZUO__.<,/A9?^__\/MT0D*"7_`0``/<`!
M```/A8+^__](B>_HQ=7__[_,4T``2(G%,<#H8N___TB%P$B)QP^$"P$``.AU
MT___28L_2(G&Z+;Z__](A<!)B<0/A.\```!,B>?H-M;__X/X`T&)P`^/904`
M`#'`Z#_O__^%P'46,?9,B>?H%=7__X7`B40D'`^%P@```+[#5$``O[930``Q
MP.CT\?__Z-/5__](BTPD$$&)P$&Y6%5``$R)\KXB54``2(GO,<`QV^@!UO__
MZSKH2M3__X,X$69FD'4_Z)W5__](BTPD$(/#`4&)P$&)V4R)\KXP54``2(GO
M,<!(QP0D6%5``.C%U?__OL`!``!(B>_HR-3__X/``72T3(GWZ`O5__](B>Z_
M*U1``#'`Z&CQ__](B>_H<//__^E__?__N]Y40`#I\/O__Y#H#]7__TV+)^D)
M____N@(```!(Q\;N____B<?HQ-/__XM\)!Q(C;0D$`$``+H&````Z#[5__^`
MO"00`0```'4.@+PD$0$``$,/A-@$``"+?"0<,?8QTDR-I"00@0``Z('3__^_
MB:O-[[[^W+J8N?#ATL-(QX0D$($```$C16=(B;PD&($``$F#Q#A(B;0D(($`
M`$C'A"0H@0``=E0R$$B)C"0P@0``2,>$)#B!````````2,>$)$"!````````
MQX0DB($```````"+?"0<2(VT)!`!``"Z`(```.B5U/__A<!!B<4/CCH!``!(
MBXPD.($``$ECU4B+A"1`@0``2(V<)!`!``"---%(.<Y(B;0D.($``$B#T`!(
MP>H=2(F$)$"!``!(`90D0($``(N4)(B!``"%TG1IZ84```!F9I!FD$B+`TB-
MO"00@0``08/M0$B)A"1(@0``2(M#"$F)1"0(2(M#$$F)1"002(M#&$F)1"08
M2(M#($F)1"0@2(M#*$F)1"0H2(M#,$F)1"0P2(M#.$B#PT!)B40D..B1U?__
M08/]/W^;26/52(G>3(GGZ!'3__]$B:PDB($``.D)____N$````!(8_I(C;0D
M$`$``"G028T\/$$YQ8G#00].W4QC^TR)^NC:TO__B=@#A"2(@0``@_A`B80D
MB($```^%QO[__TB-C"00`0``02G=2(V\)!"!``!)C1P/Z!'5___I>____XM\
M)!SH]]'__TB+G"0X@0``3(ND)$"!``!(B=A(P>@#@^`_2&/0@\`!@_@XQH04
M2($``(`/CJ<"``!(8_BZ0````#'V*<)(C;P\2($``$ACTN@JT?__2(V\)!"!
M``#HJ=3__TB-O"00@0``N0<````QP/Q(@\<X\TBK3(G@2(V\)!"!``!$B*0D
M@X$``$C!Z!B(G"2'@0``3(V\))"!``"(A"2`@0``3(G@3(VL),"!``!(P>@0
MB(0D@8$``$R)X$V)_$C!Z`B(A"2"@0``2(G82,'H&(B$)(2!``!(B=A(P>@0
MB(0DA8$``$B)V#';2,'H"(B$)(:!``#H#=3__TB+E"00@0``2(G0B)0DPX$`
M`$C!Z!B(A"3`@0``2(G02,'H$(B$),&!``!(B=!(BY0D&($``$C!Z`B(A"3"
M@0``2(G0B)0DQX$``$C!Z!B(A"3$@0``2(G02,'H$(B$),6!``!(B=!(BY0D
M(($``$C!Z`B(A"3&@0``2(G0B)0DRX$``$C!Z!B(A"3(@0``2(G02,'H$(B$
M),F!``!(B=!(BY0D*($``$C!Z`B(A"3*@0``2(G0B)0DSX$``$C!Z!B(A"3,
M@0``2(G02,'H$(B$),V!``!(B=!(BY0D,($``$C!Z`B(A"3.@0``2(G0B)0D
MTX$``$C!Z!B(A"30@0``2(G02,'H$(B$)-&!``!(B=!(P>@(B(0DTH$``$(/
MMA0K3(GG,<"^Y51``$B#PP%)@\0"Z"C1__](@_L4==[&A"2X@0```$&Y6%5`
M`$V)^$B+3"003(GROA-50`!(B>\QP.CZT/__Z4+[__](F+\)54``28UT!/RX
M!0```/Q(B<'SI@^%?OK__T&#^`1T&4&-0/Q(BU0D$$B800^V1`3_.@(/A5_Z
M__])BU\(2(7;#X12^O__2(G?Z'30__](@_@##X9`^O__2(UT`_R_#E5``+D%
M````_/.F3`]$X^DE^O__NC@```!(8_@Q]BG"2(V\/$B!``!(8]+H@\[__^EX
M_?__@+PD$@$``$$/A1K[__^`O"03`0``0P^%#/O__X"\)!0!``!(#X7^^O__
M@+PD%0$``$4/A?#Z__^+?"0<N@(```!(Q\;&____Z''.__^+?"0<2(VT)!`!
M``"Z*0```.CKS___3(V$)!`!``!!N5A50`#IU_[__V9F9I!(B5PDZ$B);"3P
M3(ED)/A(@>PX"```2(V<)!`$``!(BP5[>!``2(F$)!@(```QP.A@S___N4%5
M0`")PKY&54``,<!(B=_HFL___X7`>38Q[4B+E"08"```2#,507@0`$B)Z'5@
M2(N<)"`(``!(BZPD*`@``$R+I"0P"```2('$.`@``,-(B=^Z``0``$B)YNAP
MS___A<")PWBTC7@!2&/_Z%_.__](A<!TI$ACVTB)Q4B)YDB)VDB)Q^AFSO__
MQ@0K`.N,Z*O.__]F9F:09F:0Z2O___]F9F:09F9FD&9FD$%4,<"_#U1``,8%
M"'@0``%54^BYY___2(7`=`F`.#$/A*,!```QP.C4[?__N@L```"^`0```+]2
M54``Z+3-__](A<`/A(`````Q[8,]3GP0``%(BT`03(M@*'Y<NP@```#K*DB+
M=Q!(BP4Z?!``2(L\&.@-S?__A<!U/8/%`4B#PPB-10$Y!15\$`!^*S'2B>Y,
MB>?H*\[__TB%P'0:2(LX]D<-!'6\,?:Z`@```.@!R___2(G&ZZ^+%>)[$`"-
M0O\YZ`^$T@```+H$````O@$```"_5U5``.@7S?__2(7`2(G#=")(BT`0OEE5
M0`!(BSCHGLO__TB+0Q!(BSCV1PY`#X74````N@0```"^`0```+]G5$``Z-G,
M__](A<!(B<5T)S'`OTA40`#HH>;__TB%P$B)P@^$T0```$B+11!(B=9(BSCH
M2LO__S'`ORM40`#&!<!V$```2,<%5780``````#H:.;__TB%P$B)!29[$`!T
M=K[``0``2(G'Z)/,__^%P'01@_@1=`R#^/]F9I`/A9\```!;74%<PX/J`6:0
M#XXC____NP$```!F9I!FD$R)YX/#`>A)RO__.1W?>A``?^WI`?___X!X`0!F
M9F:0#X16_O__Z4K^__]F9I!FD.@ORO__Z1W___](BSVW>A``Z/KR__](A<!(
MB068>A``=6V_<%9``.B(R?__Z-_]__](A<!(B<-T.TB+11!(B=Y(BSCH;,K_
M_TB)W^@TS/__Z17___^)P4B+!6IZ$`!(BQ53>A``O\!60`!(BS`QP.A`R?__
M2(M5$$B+!4EZ$`!(BSI(BS#H*LK__^G;_O__2(M%$$B+'2YZ$`!(BSCV1PT$
M=#I(BW\02(G>Z#7)__^)PTB+11!(BSCV1PT$=#!(BT<02(G"2(L%_'D0`(G9
MOYA60`!(BS`QP.C7R/__N@(````Q]NCKR/__2(G'Z[FZ`@```#'VZ-K(___K
MQF9F9I"Z7E5``+Z$'4``OVA50`#IL,G__V9F9I!F9F:09F9FD$B#[`CHU___
M_[E854``13'`OO!/0`!(B<J_A%5``$B#Q`CI_<C__Y"0D)"0D)"0D%5(B>53
M2(/L"$B+!5!R$`!(@_C_=!4QV__02(N#>,50`$B#ZPA(@_C_=>U(@\0(6\G#
MD)!(@^P(Z)/,__](@\0(PP```````"1&<F5E0E-$.B!R96QE;F<O."XS+VQI
M8B]C<W4O86UD-C0O8W)T:2Y3(#$R-S(U,B`R,#`T+3`S+3(Q(#`Q.C,Y.C`Q
M6B!P971E<B`D`%!!4E]#3$5!3@`N+@`E<R\E<P!,24)0051(`$193$1?3$E"
M4D%265]0051(`%-(3$E"7U!!5$@`4$523#5,24(`4$523$Q)0@!015),-4]0
M5`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]414U0
M`%!!4E]$14)51P!005)?0T%#2$4`4$%27U!23T=.04U%`%!!4E]!4D=#`%!!
M4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!0
M05)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!
M4E]#3$5!3CT`,0!P87(M`"UE`"TM`%5315(`55-%4DY!344`4UE35$5-`"4P
M,G@`5$5-4$1)4@!435``+W9A<B]T;7`O`"5S)7,E<R5S`'!A<FP`+G!A<@`E
M<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`
M9FEL90`O<')O8R\E:2\E<P!!4D=6`!@`<&5R;`!P97)L>'-I+F,`1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`#H`
M``````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````
M_E1```````"954```````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!E>&5C=71I;VX@;V8@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M```````C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES
M('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T
M:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?
M=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@
M8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@
M=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O
M;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@
M("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@
M9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S
M(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H
M(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@
M9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@
M("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E
M(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@
M;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A8
M6"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@
M("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I
M;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[
M(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R
M7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*
M("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA
M;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@
M<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@
M("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@
M*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]
M("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@
M+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'
M5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@
M9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I
M9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?
M97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO
M(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H
M*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@
M86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T
M7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O
M9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA
M;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@
M("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@
M("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K
M(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K
M(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE
M;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@
M("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A
M8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U
M="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@
M("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@
M("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U
M-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@
M("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL
M92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0
M?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F
M:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L
M;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@
M("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C
M<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@
M("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@
M("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I
M;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@
M>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK
M97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL
M97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?
M.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O
M<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@
M(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P
M*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I
M;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H
M)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@
M("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@
M3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L
M:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO
M861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R
M<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G
M<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O
M=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R
M(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N
M<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@
M87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM
M<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@
M/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS
M=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@
M("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@
M(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P
M=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@
M=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F
M(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL
M;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I
M"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@
M("`@("`@('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@
M("!W:&EL92`H0$%21U8I('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@
M(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T
M;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G32<I('L*("`@("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@
M("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@
M("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE
M(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2![
M"B`@("`@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@
M(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P
M96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D
M,CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*
M("`@("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@
M("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@
M("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E
M(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X
M:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A
M<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H
M86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!
M<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@
M("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@
M('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@
M("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@
M3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@
M/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM
M;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R
M96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E
M*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@
M('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@
M("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V
M86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@
M("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@
M("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@
M)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D
M<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A
M9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@
M8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@
M(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="![
M"B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@
M("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R
M97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@
M("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T
M97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@
M;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W
M+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M
M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@
M("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O
M9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)
M(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@
M("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K
M97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#
M.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H
M<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F
M:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@
M("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@
M("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<
M6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H
M)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO
M72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER
M+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE
M*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN
M960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@
M("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@
M("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@
M("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@
M(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D
M:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I
M;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%
M/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@
M("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@
M("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@
M("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E
M,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I
M+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]
M?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I
M;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@
M("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O
M<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y
M"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I
M.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@
M(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?
M;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D[
M"B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H
M)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@
M("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*
M"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@
M4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@
M;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C
M:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#
M=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@
M("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV
M93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N
M*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!0
M05(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!]
M(BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*
M("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD
M0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_
M.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@
M("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@
M("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E
M<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M
M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E
M)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@
M("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I
M(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M
M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ
M9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@
M1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D
M+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E
M<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER
M92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A
M<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@
M("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@
M("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T
M97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP
M.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E
M<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE
M.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@
M4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z
M.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@
M(')E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*("`@(')E<75I
M<F4@871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@
M979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ
M:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PH@("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U
M:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T
M:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C
M;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T
M96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@
M('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@
M("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@
M)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@
M("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN
M960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I
M9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@
M('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY
M("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K
M*")(*B(L("1U<V5R;F%M92D["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W
M-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@
M*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F
M:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@
M-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@
M("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@
M<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]
M?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*
M("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@
M("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G
M(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@
M(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@
M("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF
M("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M
M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H
M)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%
M04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@
M("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R
M7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@
M("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E
M('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D
M9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M
M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H
M+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E
M='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92![
M"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@
M/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q
M*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@
M(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@
M("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US
M("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@
M("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B
M(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C
M:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E
M('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*
M("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6
M>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?
M5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@
M?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K
M(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*
M<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G
M9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@
M96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI
M=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@
M("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D[
M"GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A
M8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*"C$["@HC;&EN92`Q,#$Q"@I?7T5.1%]?"@``````````````````
M`,!#)$9R965"4T0Z(')E;&5N9R\X+C,O;&EB+V-S=2]A;60V-"]C<G1N+E,@
M,3(W,C4R(#(P,#0M,#,M,C$@,#$Z,SDZ,#%:('!E=&5R("0````!&P,[#`T0
M`!D````X;/__*`T0`$AM__]0#1``B&W__V@-$`!X@___F`T0`%B$___`#1``
MJ(3__^`-$`#(A/__^`T0`!B%__\0#A``.(7__R@.$``(AO__0`X0`%B'__]@
M#A``J(?__X`.$`"XB?__N`X0`-B*___P#A``F(S__P@/$`#(C/__(`\0`+B-
M__]`#Q``*([__U@/$``8D/__>`\0`,B1__^P#Q``^)O__^@/$`#(G/__"!`0
M`-B<__\@$!``N)___T`0$`#8G___6!`0````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````6%5``````````````````)C%4```````"%=```````#_
M____`````!0``````````7I2``%X$`$##`<(D`$``"0````<````4!]``)P`
M````00X0A@)##09"C0-+@P6,!``````````4````1````&`@0``T````````
M```````L````7````*`@0`#P%0```$(.$$8.&$(.($$.*(8%C`2-`XX"1`XP
M1PZX!(,&```D````C````)`V0`#9`````$J/`HP%7@Y`C@.-!(8&@P<`````
M````'````+0```!P-T``3P````!!#A!!#AB#`X8"1PXP```4````U````,`W
M0``5`````$0.(``````4````[````.`W0`!-`````$0.$``````4````!`$`
M`#`X0``>`````$0.$``````4````'`$``%`X0`#"`````$@.$(,"```<````
M-`$``"`Y0`!"`0```$J#!HP$60ZP`8X"C0.&!1P```!4`0``<#I``$\`````
M00X0@P)'#I`!````````-````'0!``#`.D``!0(```!"#A!$#AB.`X\"10X@
M0@XH00XPA@:,!8T$1`XX1`Y0@P<````````T````K`$``-`\0``7`0```$(.
M$$(.&(X#CP)%#B!"#BB,!8T$1PXP00XX1`Z``8,'A@8``````!0```#D`0``
M\#U``+X!````1`Y``````!0```#\`0``L#]``"(`````1`X0`````!P````4
M`@``X#]``.(`````00X000X8@P.&`D<.(```%````#0"``#00$``;0````!.
M#B"&`H,#'````$P"``!`04``\`$```!!#A!$#C"#`@`````````T````;`(`
M`#!#0`"L`0```$(.$$(.&$(.($(.*(P%C02.`X\"20XP00XX@P>&!DH.X`D`
M`````#0```"D`@``X$1``"P*````0@X0CP)*#AA"#B!"#BA!#C!!#CA'#J"$
M`H,'A@:,!8T$C@,`````'````-P"```03T``R0````!6#L`0C`*&`X,$````
M```4````_`(``.!/0``%```````````````<````%`,``/!/0`#<`@```$(.
M$$\.&$$.((,$A@.,`A0````T`P``T%)``!0``````````````!0```!,`P``
M\%)``"<`````1`X0`````````````````0`````````!``````````$`````
M````'0(````````!`````````"<"`````````0`````````U`@````````$`
M````````0@(````````!`````````&8"````````#P````````"/`P``````
M``P`````````8!M````````-`````````%130```````!`````````#X`4``
M``````4`````````L`Y````````&`````````"`%0```````"@````````"S
M!`````````L`````````&``````````5`````````````````````P``````
M``"HQ5````````(`````````H`4````````4``````````<`````````%P``
M``````#`%4````````<`````````<!1````````(`````````%`!````````
M"0`````````8`````````/[__V\`````,!1```````#___]O``````(`````
M````\/__;P````!D$T``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/__________``````````#_____
M_____P````````````````````"0PU````````````````````````````"*
M&T```````)H;0```````JAM```````"Z&T```````,H;0```````VAM`````
M``#J&T```````/H;0```````"AQ````````:'$```````"H<0```````.AQ`
M``````!*'$```````%H<0```````:AQ```````!Z'$```````(H<0```````
MFAQ```````"J'$```````+H<0```````RAQ```````#:'$```````.H<0```
M````^AQ````````*'4```````!H=0```````*AU````````Z'4```````$H=
M0```````6AU```````!J'4```````'H=0```````BAU```````":'4``````
M`*H=0```````NAU```````#*'4```````-H=0```````ZAU```````#Z'4``
M``````H>0```````&AY````````J'D```````#H>0```````2AY```````!:
M'D```````&H>0```````>AY```````"*'D```````)H>0```````JAY`````
M``"Z'D```````,H>0```````VAY```````#J'D```````/H>0```````"A]`
M```````:'T```````"H?0```````.A]`````````)$9R965"4T0Z(')E;&5N
M9R\X+C,O;&EB+V-S=2]C;VUM;VXO8W)T8G)A;F0N8R`Q-S0R-3$@,C`P-RTQ
M,BTP-"`Q,CHQ.#HT,UH@:VEB("0`)$9R965"4T0Z(')E;&5N9R\X+C,O;&EB
M+V-S=2]A;60V-"]C<G0Q+F,@,34Q,#<R(#(P,#4M,3`M,#<@,C(Z,3,Z,3=:
M(&)D92`D`$=#0SH@*$=.52D@-"XR+C(@,C`P-S`X,S$@<')E<F5L96%S92!;
M1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C(@,C`P-S`X,S$@<')E<F5L96%S
M92!;1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C(@,C`P-S`X,S$@<')E<F5L
M96%S92!;1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C(@,C`P-S`X,S$@<')E
M<F5L96%S92!;1G)E94)31%T``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"
M22UT86<`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU
M+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF
M:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N9&%T80`N96A?9G)A;64`+F1Y
M;F%M:6,`+F-T;W)S`"YD=&]R<P`N:F-R`"YG;W0`+F)S<P`N8V]M;65N=```
M````````````````````````````````````````````````````````````
M```````````````````````````````+`````0````(`````````R`%`````
M``#(`0```````!4````````````````````!````````````````````$P``
M``<````"`````````.`!0```````X`$````````8````````````````````
M!````````````````````"$````%`````@````````#X`4```````/@!````
M````)`,````````$``````````@`````````!``````````G````"P````(`
M````````(`5````````@!0```````)`)````````!0````$````(````````
M`!@`````````+P````,````"`````````+`.0```````L`X```````"S!```
M`````````````````0```````````````````#<```#___]O`@````````!D
M$T```````&03````````S``````````$``````````(``````````@``````
M``!$````_O__;P(`````````,!1````````P%````````$``````````!0``
M``(````(````````````````````4P````0````"`````````'`40```````
M<!0```````!0`0````````0`````````"``````````8`````````%T````$
M`````@````````#`%4```````,`5````````H`4````````$````"P````@`
M````````&`````````!G`````0````8`````````8!M```````!@&P``````
M`!,````````````````````$````````````````````8@````$````&````
M`````'0;0```````=!L```````#0`P``````````````````!``````````0
M`````````&T````!````!@````````!0'T```````%`?````````!#0`````
M`````````````!````````````````````!S`````0````8`````````5%-`
M``````!44P````````X````````````````````$````````````````````
M>0````$````"`````````&A30```````:%,```````"N7P``````````````
M````"````````````````````($````!`````@`````````8LT```````!BS
M````````U`````````````````````0```````````````````"/`````0``
M``,``````````,!0````````P````````"0````````````````````(````
M````````````````E0````$````"`````````"C`4```````*,````````!D
M`P``````````````````"````````````````````)\````&`````P``````
M``"0PU```````)##````````\`$````````%``````````@`````````$```
M``````"H`````0````,`````````@,50``````"`Q0```````!``````````
M```````````(````````````````````KP````$````#`````````)#%4```
M````D,4````````0````````````````````"````````````````````+8`
M```!`````P````````"@Q5```````*#%````````"```````````````````
M``@```````````````````"[`````0````,`````````J,50``````"HQ0``
M`````/@!```````````````````(``````````@`````````P`````@````#
M`````````*#'4```````H,<````````(!0``````````````````(```````
M`````````````,4````!`````````````````````````*#'````````70$`
M``````````````````$````````````````````!`````P``````````````
M``````````#]R````````,X````````````````````!````````````````
#````
